==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/monitor/views.py <==
from django.contrib.auth.decorators import login_required
from django.contrib.auth.mixins import LoginRequiredMixin
from django.shortcuts import render
from django.views.generic import TemplateView

from spread_core import mqtt
from spread_core.protocols.dali.gear import general as d1
from spread_core.protocols.payloads.dali import Dali2Command, DaliCommand, Dali2Event
from spread_dashboard.project import bam


@login_required
def index(request):
    return render(request, 'monitor/index.html', dict(
        buses=[
            dict(name=bam.Dali.__name__.lower(),
                 items=sorted(bam.models.Manager.objects.filter(type=bam.Dali.__name__), key=lambda m: m.attributes['bus'])),
            dict(name=bam.Mercury.__name__.lower(),
                 items=sorted(bam.models.Manager.objects.filter(type=bam.Mercury.__name__), key=lambda m: m.attributes['bus']))
        ]
    ))


class Dali(LoginRequiredMixin, TemplateView):
    template_name = 'monitor/dali.html'

    def get(self, request, *args, **kwargs):
        single_id = request.GET.get('manager_id', False)
        if single_id:
            single = True
            items = [bam.models.Manager.objects.get(id=int(single_id))]
        else:
            single = False
            items = sorted(bam.models.Manager.objects.filter(type=bam.Dali.__name__), key=lambda m: m.attributes['bus'])

        return self.render_to_response(context=dict(
            topics=[str(mqtt.bus.TopicBus.of_dump('')), str(mqtt.bus.TopicBus.of_send(''))],
            marks=[[DaliCommand.mark, Dali2Command.mark, Dali2Event.mark]],
            names=[[d1.DAPC.__name__, d1.Off.__name__], [d1.GoToScene.__name__, d1.GoToLastActiveLevel.__name__],
                   [d1.RecallMinLevel.__name__, d1.RecallMaxLevel.__name__], [d1.StepDown.__name__, d1.StepUp.__name__],
                   [d1.QueryStatus.__name__, d1.QueryActualLevel.__name__], [d1.IdentifyDevice.__name__]],
            addresses=[range(i*8, i*8+8) for i in range(0, 8)],
            groups=[range(i*4, i*4+4) for i in range(0, 4)],
            single=single,
            bus=dict(name=bam.Dali.__name__.lower(), items=items),
            socket='/spread/ws/monitor/' + ('raw_dali/' if 'raw' in request.GET else 'dali/')
        ))

==> spread-5.7.0.72-py3-none-any.whl: spread_dashboard/monitor/views.py <==
from django.contrib.auth.decorators import login_required
from django.contrib.auth.mixins import LoginRequiredMixin
from django.shortcuts import render
from django.views.generic import TemplateView

from spread_dashboard.project import bam


@login_required
def index(request):
    return render(request, 'monitor/index.html', dict(
        buses=[
            dict(name=bam.Dali.__name__.lower(),
                 items=sorted(bam.models.Manager.objects.filter(type=bam.Dali.__name__), key=lambda m: m.attributes['bus'])),
            dict(name=bam.Mercury.__name__.lower(),
                 items=sorted(bam.models.Manager.objects.filter(type=bam.Mercury.__name__), key=lambda m: m.attributes['bus']))
        ]
    ))


class Dali(LoginRequiredMixin, TemplateView):
    template_name = 'monitor/dali.html'

    def get(self, request, *args, **kwargs):

        from spread_core import mqtt

        from spread_dali.gear import general as gear
        from spread_dali.payloads import Dali2Command, DaliCommand, Dali2Event

        single_id = request.GET.get('manager_id', False)
        if single_id:
            single = True
            items = [bam.models.Manager.objects.get(id=int(single_id))]
        else:
            single = False
            items = sorted(bam.models.Manager.objects.filter(type=bam.Dali.__name__), key=lambda m: m.attributes['bus'])

        return self.render_to_response(context=dict(
            topics=[str(mqtt.bus.TopicBus.of_dump('<PART>')), str(mqtt.bus.TopicBus.of_send('<PART>'))],
            marks=[[DaliCommand.mark, Dali2Command.mark, Dali2Event.mark]],
            names=[[gear.DAPC.__name__, gear.Off.__name__], [gear.GoToScene.__name__, gear.GoToLastActiveLevel.__name__],
                   [gear.RecallMinLevel.__name__, gear.RecallMaxLevel.__name__], [gear.StepDown.__name__, gear.StepUp.__name__],
                   [gear.QueryStatus.__name__, gear.QueryActualLevel.__name__], [gear.IdentifyDevice.__name__]],
            addresses=[range(i*8, i*8+8) for i in range(0, 8)],
            groups=[range(i*4, i*4+4) for i in range(0, 4)],
            single=single,
            bus=dict(name=bam.Dali.__name__.lower(), items=items),
            socket='/spread/ws/monitor/' + ('raw_dali/' if 'raw' in request.GET else 'dali/')
        ))
